# This file was auto-generated by Fern from our API Definition.

import typing

StatusContext = typing.Union[
    typing.Literal[
        "broker_license",
        "investment_advisor_license",
        "sole_proprietorship_status",
        "general_partnership_status",
        "limited_liability_partnership_status",
    ],
    typing.Any,
]
