# This file was auto-generated by Fern from our API Definition.

import typing

SearchField = typing.Union[
    typing.Literal["name", "identifier", "address", "business_purpose", "date_of_birth", "contact"], typing.Any
]
