# This file was auto-generated by Fern from our API Definition.

from .types import MatchExplanation, ResolutionResponse, ResolutionResponseFields, ResolutionResult

__all__ = ["MatchExplanation", "ResolutionResponse", "ResolutionResponseFields", "ResolutionResult"]
